@@ -2,6 +2,7 @@ from django import template
 from ..models import Post, CATEGORY
 from ..forms import Search
 from _data.blog import context
+import re
 
 register = template.Library()
 
@@ -13,6 +14,11 @@ def get_category_display(value):
     return value.get_category_display()
 
 
+@register.filter
+def remove_html_tags(value):
+    return re.sub('(<([^>]+)>)', '', value)
+
+
 @register.inclusion_tag('zenblog/index/_hero_slider.html')
 def show_hero_slider():
     return {
